from dartcms.utils.config import DartCMSConfig
from dartcms.views import DeleteObjectView, GridView
from django.conf.urls import url
from django.utils.translation import ugettext_lazy as _

from .forms import UserForm
from .models import CMSUser
from .views import ChangePasswordView, CMSUserInsertView, CMSUserUpdateView

app_name = "users"

config = DartCMSConfig({
    'model': CMSUser,
    'grid': {
        'grid_columns': [
            {'field': CMSUser.USERNAME_FIELD, 'width': '60%'},
            {'field': 'last_login', 'width': '20%'},
            {'field': 'is_staff', 'width': '10%'},
            {'field': 'is_active', 'width': '10%'},
        ],
        'search': [
            CMSUser.USERNAME_FIELD, 'email'
        ],
        'additional_grid_actions': [
            {
                'url': 'change-password', 'label': _('Change Password'), 'icon': 'edit',
                'required_permissions': '__all__', 'kwarg_name': 'pk'
            }
        ],
        'model_properties': [CMSUser.USERNAME_FIELD]
    },
    'form': {
        'form_class': UserForm
    }
})

urlpatterns = config.get_urls(exclude=['addition', 'insert', 'update', 'delete']) + [
    url(r'^$', GridView.as_view(**config.grid), name='index'),
    url(r'^insert/$', CMSUserInsertView.as_view(**config.form), name='insert'),
    url(r'^update/(?P<pk>\d+)/$', CMSUserUpdateView.as_view(**config.form), name='update'),
    url(r'^delete/(?P<pk>\d+)/$', DeleteObjectView.as_view(**config.base), name='delete'),
    url(r'^change-password/(?P<pk>\d+)/$', ChangePasswordView.as_view(), name='change_password'),
]



from dartcms.utils.config import DartCMSConfig
from django.conf.urls import url
from django.utils.translation import ugettext_lazy as _

from .views import (DeleteMessageFormView, InsertMessageFormView,
                    MessagesGridView, UpdateMessageFormView)

app_name = 'feedback_messages'

config = DartCMSConfig({
    'parent_kwarg_name': 'form_type',
    'parent_model_fk': 'type_id',
    'grid': {
        'base_grid_actions': ['update', 'delete', 'insert'],
        'grid_columns': [
            {'field': 'author', 'width': '80%', 'label': _('Author')},
            {'field': 'date_created', 'width': '20%', 'label': _('Date_created')},
        ]
    }
})

urlpatterns = [
    url(r'^$', MessagesGridView.as_view(**config.grid), name='index'),
    url(r'^insert/$', InsertMessageFormView.as_view(**config.form), name='insert'),
    url(r'^update/(?P<pk>\d+)/$', UpdateMessageFormView.as_view(**config.form), name='update'),
    url(r'^delete/(?P<pk>\d+)/$', DeleteMessageFormView.as_view(**config.base), name='delete'),
]



from dartcms.utils.loading import get_model
from django import forms


class FeedItemForm(forms.ModelForm):
    class Meta:
        model = get_model('feeds', 'FeedItem')
        exclude = ['feed', 'slug']



# Generated by Django 1.9.7 on 2016-07-12 15:04
from __future__ import unicode_literals

import datetime

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SiteSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(max_length=30, unique=True, verbose_name='Identifier')),
                ('description', models.TextField(default=b'', verbose_name='Description')),
                ('type', models.CharField(blank=True, choices=[(b'text', 'String'), (b'textarea', 'Text'), (b'rich', 'Rich Editor'), (b'select', 'Select'), (b'date', 'Date'), (b'file', 'File')], default=b'text', max_length=10, verbose_name='Type')),
                ('text_value', models.TextField(blank=True, default=b'', verbose_name='Value for text type')),
                ('date_value', models.DateTimeField(blank=True, default=datetime.datetime.now, null=True, verbose_name='Value for date type')),
                ('file_value', models.FileField(blank=True, null=True, upload_to=b'vars', verbose_name='Value for file')),
                ('options', models.TextField(blank=True, default=b'', verbose_name='Options for select type (use ";" as separator)')),
            ],
            options={
                'ordering': ['slug'],
                'verbose_name': 'Site setting',
                'verbose_name_plural': 'Site settings',
            },
        ),
    ]



# Generated by Django 1.9.7 on 2016-07-14 12:23
from __future__ import unicode_literals

import autoslug.fields
import dartcms.utils.fields
import django.db.models.deletion
import django.db.models.manager
import mptt.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('description', dartcms.utils.fields.RteField(blank=True, default=b'', verbose_name='Description')),
                ('seo_keywords', models.TextField(blank=True, default=b'', verbose_name='Keywords (meta keywords)')),
                ('seo_description', models.TextField(blank=True, default=b'', verbose_name='Keywords (meta keywords)')),
                ('is_visible', models.BooleanField(default=True, verbose_name='Is Visible')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('slug', autoslug.fields.AutoSlugField(editable=False, populate_from=b'name', unique=True, verbose_name='URL')),
                ('code', models.CharField(blank=True, default=b'', max_length=100, verbose_name='Code')),
                ('short_description', dartcms.utils.fields.RteField(blank=True, default=b'', verbose_name='Short description')),
                ('residue', models.IntegerField(default=1, verbose_name='Residue')),
                ('price', models.DecimalField(decimal_places=2, default=0, max_digits=10, verbose_name='Price')),
                ('image', models.ImageField(blank=True, null=True, upload_to=b'shop/product/%Y/%m/%d', verbose_name='Image')),
            ],
            options={
                'ordering': ['name'],
                'abstract': False,
                'verbose_name': 'product',
                'verbose_name_plural': 'products',
            },
        ),
        migrations.CreateModel(
            name='ProductCatalog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('description', dartcms.utils.fields.RteField(blank=True, default=b'', verbose_name='Description')),
                ('seo_keywords', models.TextField(blank=True, default=b'', verbose_name='Keywords (meta keywords)')),
                ('seo_description', models.TextField(blank=True, default=b'', verbose_name='Keywords (meta keywords)')),
                ('is_visible', models.BooleanField(default=True, verbose_name='Is Visible')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('slug', models.SlugField(unique=True, verbose_name='URL')),
                ('image', models.ImageField(blank=True, null=True, upload_to=b'shop/catalog', verbose_name='Image')),
            ],
            options={
                'ordering': ['name'],
                'abstract': False,
                'verbose_name': 'product catalog',
                'verbose_name_plural': 'product catalogs',
            },
        ),
        migrations.CreateModel(
            name='ProductImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to=b'shop/product_images/%Y/%m/%d', verbose_name='Image')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pictures', to='shop.Product', verbose_name='Product')),
            ],
            options={
                'ordering': ['-date_created'],
                'abstract': False,
                'verbose_name': 'product picture',
                'verbose_name_plural': 'product pictures',
            },
        ),
        migrations.CreateModel(
            name='ProductLabel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('description', dartcms.utils.fields.RteField(blank=True, default=b'', verbose_name='Description')),
                ('seo_keywords', models.TextField(blank=True, default=b'', verbose_name='Keywords (meta keywords)')),
                ('seo_description', models.TextField(blank=True, default=b'', verbose_name='Keywords (meta keywords)')),
                ('is_visible', models.BooleanField(default=True, verbose_name='Is Visible')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('slug', models.SlugField(unique=True, verbose_name='URL')),
                ('image', models.ImageField(blank=True, null=True, upload_to=b'shop/label', verbose_name='Image')),
            ],
            options={
                'ordering': ['name'],
                'abstract': False,
                'verbose_name': 'product label',
                'verbose_name_plural': 'product labels',
            },
        ),
        migrations.CreateModel(
            name='ProductSection',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('description', dartcms.utils.fields.RteField(blank=True, default=b'', verbose_name='Description')),
                ('seo_keywords', models.TextField(blank=True, default=b'', verbose_name='Keywords (meta keywords)')),
                ('seo_description', models.TextField(blank=True, default=b'', verbose_name='Keywords (meta keywords)')),
                ('is_visible', models.BooleanField(default=True, verbose_name='Is Visible')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('slug', autoslug.fields.AutoSlugField(editable=False, populate_from=b'name', unique=True, verbose_name='URL')),
                ('image', models.ImageField(blank=True, null=True, upload_to=b'shop/section', verbose_name='Image')),
                ('sort', models.IntegerField(default=1)),
                ('lft', models.PositiveIntegerField(db_index=True, editable=False)),
                ('rght', models.PositiveIntegerField(db_index=True, editable=False)),
                ('tree_id', models.PositiveIntegerField(db_index=True, editable=False)),
                ('level', models.PositiveIntegerField(db_index=True, editable=False)),
                ('catalog', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='sections', to='shop.ProductCatalog', verbose_name='Product catalog')),
                ('parent', mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='shop.ProductSection', verbose_name='Parent Section')),
            ],
            options={
                'ordering': ['sort'],
                'abstract': False,
                'verbose_name': 'product section',
                'verbose_name_plural': 'product sections',
            },
            managers=[
                ('objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='product',
            name='labels',
            field=models.ManyToManyField(blank=True, related_name='label_products', to='shop.ProductLabel', verbose_name='Labels'),
        ),
        migrations.AddField(
            model_name='product',
            name='section',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products', to='shop.ProductSection', verbose_name='Section'),
        ),
        migrations.AlterUniqueTogether(
            name='productsection',
            unique_together=set([('catalog', 'slug')]),
        ),
    ]



from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _
from jsonfield import JSONField


class ModuleGroup(models.Model):
    class Meta:
        verbose_name_plural = _('Module Groups')
        verbose_name = _('Module Group')
        ordering = ['sort']

    def __str__(self):
        return self.name

    slug = models.SlugField(unique=True, verbose_name=_('Slug'))
    name = models.CharField(max_length=64, verbose_name=_('Name'))
    fa = models.SlugField(verbose_name=_('FontAwesome class'))
    sort = models.IntegerField(default=1, verbose_name=_('Sort'))
    description = models.TextField(default='', verbose_name=_('Description'),
                                   blank=True)


class Module(models.Model):
    class Meta:
        verbose_name_plural = _('Modules')
        verbose_name = _('Module')
        ordering = ['group', 'sort']

    def __str__(self):
        return self.group.name + ' / ' + self.name

    group = models.ForeignKey(ModuleGroup, to_field='slug', verbose_name=_('Group'),
                              related_name='modules',
                              on_delete=models.CASCADE)
    name = models.CharField(max_length=64, verbose_name=_('Name'))
    sort = models.IntegerField(default=1, verbose_name=_('Sort'))
    description = models.TextField(default='', verbose_name=_('Description'),
                                   blank=True)
    slug = models.SlugField(unique=True, verbose_name=_('Slug'))
    config = JSONField(null=True, blank=True, verbose_name=_('Config'))
    user = models.ManyToManyField(to=settings.AUTH_USER_MODEL, verbose_name=_('User'))
    is_enabled = models.BooleanField(default=True, verbose_name=_('Is Enabled'))


class ModulePermission(models.Model):
    class Meta:
        verbose_name_plural = _('Module permissions')
        verbose_name = _('Module permission')
        ordering = ['id']

    def __str__(self):
        return str(_(f'Module permission for {self.user}, {str(self.module)}'))

    module = models.ForeignKey(Module, verbose_name=_('Module'),
                               related_name='module_permissions',
                               on_delete=models.CASCADE)
    user = models.ForeignKey(to=settings.AUTH_USER_MODEL, verbose_name=_('User'),
                             related_name='user_module_permissions',
                             on_delete=models.CASCADE)
    can_insert = models.BooleanField(default=True, verbose_name=_('Can insert data'))
    can_update = models.BooleanField(default=True, verbose_name=_('Can update data'))
    can_delete = models.BooleanField(default=True, verbose_name=_('Can delete data'))
    date_changed = models.DateTimeField(auto_now=True)



from dartcms.apps.ads.models import AdPlace
from dartcms.utils.config import DartCMSConfig
from django.forms import modelform_factory

app_name = 'adplace'

config = DartCMSConfig({
    'model': AdPlace,
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '80%'},
            {'field': 'is_enabled', 'width': '20%'},
        ],
        'base_grid_actions': ['update']
    },
    'form': {
        'form_class': modelform_factory(AdPlace, exclude=['slug']),
    },
})

urlpatterns = config.get_urls(exclude=['insert', 'delete'])



from dartcms.utils.loading import get_model
from django.utils.translation import ugettext_lazy as _
from django.forms import ModelForm


class ProductForm(ModelForm):
    class Meta:
        model = get_model('shop', 'Product')
        exclude = ['section']

        fieldsets = (
            ('main', {'fields': (
                'slug',
                'name',
                'code',
                'short_description',
                'description',
                'manufacturer',
                'residue',
                'price',
            ), 'legend': _('Main')}),
            ('seo', {'fields': (
                'seo_keywords',
                'seo_description',
            ), 'legend': _('SEO')}),
            ('advanced', {'fields': (
                'labels',
                'image',
                'is_visible',
            ), 'legend': _('Advanced')}))



# Generated by Django 1.9.6 on 2016-07-05 09:26
from __future__ import unicode_literals

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='File',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('path', models.FileField(max_length=300, upload_to=b'uploads/%Y/%m/%d')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name='Folder',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(error_messages={b'unique': 'Folder with this name is already exists'}, max_length=255, unique=True)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.AddField(
            model_name='file',
            name='folder',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='filemanager.Folder'),
        ),
    ]



from dartcms.utils.config import DartCMSConfig
from dartcms.utils.loading import get_model
from django.forms import modelform_factory

app_name = 'feeds'

Feed = get_model('feeds', 'Feed')

config = DartCMSConfig({
    'model': Feed,
    'grid': {
        'grid_columns': [
            {'field': 'type', 'width': '10%'},
            {'field': 'name', 'width': '90%'},
        ],
        'additional_grid_actions': [
            {'url': 'items', 'kwarg_name': 'feed', 'include_urls': 'dartcms.apps.feeds.items.urls'}
        ]
    },
    'form': {
        'form_class': modelform_factory(Feed, exclude=[]),
    }
})

urlpatterns = config.get_urls()



# Generated by Django 1.10.4 on 2017-08-29 05:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sitesettings', '0002_insert_settings'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sitesettings',
            name='description',
            field=models.TextField(default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='sitesettings',
            name='file_value',
            field=models.FileField(blank=True, null=True, upload_to='vars', verbose_name='Value for file'),
        ),
        migrations.AlterField(
            model_name='sitesettings',
            name='options',
            field=models.TextField(blank=True, default='', verbose_name='Options for select type (use ";" as separator)'),
        ),
        migrations.AlterField(
            model_name='sitesettings',
            name='text_value',
            field=models.TextField(blank=True, default='', verbose_name='Value for text type'),
        ),
        migrations.AlterField(
            model_name='sitesettings',
            name='type',
            field=models.CharField(blank=True, choices=[('text', 'String'), ('textarea', 'Text'), ('rich', 'Rich Editor'), ('select', 'Select'), ('date', 'Date'), ('file', 'File')], default='text', max_length=10, verbose_name='Type'),
        ),
    ]



from dartcms.apps.modules.functions import get_current_module


def modules_data(request):
    if not request.is_ajax() and request.user.is_authenticated and request.user.is_staff:
        modules = request.user.module_set.all()

        module_groups = [m.group for m in modules]
        module_groups_set = set(module_groups)

        res = dict(module_groups=module_groups_set)

        module = get_current_module(request.path)
        if module:
            res.update(
                dict(active_module_slug=module.slug,
                     active_group_slug=module.group.slug)
            )
        return res
    else:
        return {}



# Generated by Django 1.9.6 on 2016-07-05 05:21
from __future__ import unicode_literals

from django.db import migrations
from django.utils import translation
from django.utils.translation import gettext_lazy as _

PAGE_MODULES = [
    {'slug': 'feeds', 'name': _('Feeds')},
    {'slug': 'contacts', 'name': _('Contacts')},
    {'slug': 'shop', 'name': _('Shop')},
    {'slug': 'page', 'name': _('Static Page')},
]


def insert_pagemodules(apps, schema):
    from django.conf import settings
    translation.activate(settings.LANGUAGE_CODE)

    PageModule = apps.get_model('pages', 'PageModule')

    for m in PAGE_MODULES:
        PageModule.objects.create(**m)

    translation.deactivate()


def drop_pagemodules(apps, schema):
    PageModule = apps.get_model('pages', 'PageModule')

    for m in PAGE_MODULES:
        PageModule.objects.filter(slug=m['slug']).delete()


class Migration(migrations.Migration):
    dependencies = [
        ('pages', '0002_related_models'),
    ]

    operations = [
        migrations.RunPython(insert_pagemodules, drop_pagemodules)
    ]



# Generated by Django 1.10.4 on 2016-12-14 02:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0002_auto_20161214_0258'),
        ('pages', '0009_auto_20161130_1207'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='security_type',
            field=models.CharField(choices=[
                (b'DEFAULT', 'Editable for all users'),
                (b'BY_PARENT', 'Based on the parent page'),
                (b'GROUPS_ONLY', 'Editable for specific groups')
            ], default=b'BY_PARENT', max_length=16, verbose_name='Security type'),
        ),
        migrations.AddField(
            model_name='page',
            name='user_groups',
            field=models.ManyToManyField(to='users.UserGroup', verbose_name='User groups'),
        ),
    ]



from django.db import models
from django.utils import timezone
from django.utils.translation import ugettext_lazy as _
from versatileimagefield.fields import VersatileImageField


class AdPlace(models.Model):
    class Meta:
        app_label = 'ads'
        verbose_name = _('ad place')
        verbose_name_plural = _('ad places')
        ordering = ['name']

    def __str__(self):
        return self.name

    name = models.CharField(max_length=255, verbose_name=_('Name'))
    slug = models.SlugField(unique=True)
    is_enabled = models.BooleanField(default=True, verbose_name=_('Is Enabled'))


class AdSection(models.Model):
    class Meta:
        app_label = 'ads'
        verbose_name = _('ad section')
        verbose_name_plural = _('ad sections')
        ordering = ['name']

    def __str__(self):
        return self.name

    name = models.CharField(max_length=255, verbose_name=_('Name'))
    is_enabled = models.BooleanField(default=True, verbose_name=_('Is Enabled'))


class AbstractAd(models.Model):
    class Meta:
        app_label = 'ads'
        verbose_name = _('ad')
        verbose_name_plural = _('ads')
        ordering = ['name']
        abstract = True

    date_from = models.DateTimeField(default=timezone.now, verbose_name=_('Start Date'))
    date_to = models.DateTimeField(default=timezone.now, verbose_name=_('End Date'))
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    title = models.TextField(default='', blank=True, verbose_name=_('Ad Text'))
    link = models.URLField(default='', blank=True, verbose_name=_('Ad Link'))
    code = models.TextField(default='', blank=True, verbose_name=_('Embed Code'))
    bg = models.CharField(default='', blank=True, max_length=255, verbose_name=_('Background Color'))
    place = models.ForeignKey('ads.AdPlace', verbose_name=_('Ad Place'),
                              related_name='%(app_label)s_%(class)s_related', on_delete=models.CASCADE)
    views = models.IntegerField(default=0, verbose_name=_('Views'))
    section = models.ManyToManyField('ads.AdSection', verbose_name=_('Section'),
                                     related_name='%(app_label)s_%(class)s_related')
    picture = VersatileImageField(upload_to='b/%Y/%m/%d', null=True, blank=True, verbose_name=_('Picture'))
    is_enabled = models.BooleanField(default=True, verbose_name=_('Is Enabled'))
    date_created = models.DateTimeField(auto_now_add=True)
    date_changed = models.DateTimeField(auto_now=True)

    def __str__(self):
        return self.name



# Generated by Django 2.0.1 on 2018-01-23 11:13

import django.db.models.deletion
import mptt.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0008_auto_20170829_0515'),
    ]

    operations = [
        migrations.AlterField(
            model_name='product',
            name='manufacturer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='manufacturer_products', to='shop.ProductManufacturer', verbose_name='Manufacturer'),
        ),
        migrations.AlterField(
            model_name='product',
            name='section',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='products', to='shop.ProductSection', verbose_name='Section'),
        ),
        migrations.AlterField(
            model_name='productsection',
            name='catalog',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='sections', to='shop.ProductCatalog', verbose_name='Product catalog'),
        ),
        migrations.AlterField(
            model_name='productsection',
            name='parent',
            field=mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='children', to='shop.ProductSection', verbose_name='Parent Section'),
        ),
    ]



from django.conf.urls import url

from .views import LoginView, LogoutView

app_name = 'auth'

urlpatterns = [
    url(r'^login/$', LoginView.as_view(), name='login'),
    url(r'^logout/$', LogoutView.as_view(), name='logout'),
]



# Generated by Django 1.10.4 on 2017-05-26 05:59
from __future__ import unicode_literals

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('modules', '0009_insert_user_group_module'),
    ]

    operations = [
        migrations.CreateModel(
            name='ModulePermission',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('can_insert', models.BooleanField(default=True, verbose_name='Can insert data')),
                ('can_update', models.BooleanField(default=True, verbose_name='Can update data')),
                ('can_delete', models.BooleanField(default=True, verbose_name='Can delete data')),
                ('date_changed', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name': 'Module permission',
                'verbose_name_plural': 'Module permissions',
                'ordering': ['id'],
            },
        ),
        migrations.AlterField(
            model_name='module',
            name='description',
            field=models.TextField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='modulegroup',
            name='description',
            field=models.TextField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AddField(
            model_name='modulepermission',
            name='module',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='module_permissions', to='modules.Module', verbose_name='Module'),
        ),
        migrations.AddField(
            model_name='modulepermission',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='user_module_permissions', to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
    ]



# Generated by Django 1.10.4 on 2017-08-29 05:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ads', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ad',
            name='bg',
            field=models.CharField(blank=True, default='', max_length=255, verbose_name='Background Color'),
        ),
        migrations.AlterField(
            model_name='ad',
            name='code',
            field=models.TextField(blank=True, default='', verbose_name='Embed Code'),
        ),
        migrations.AlterField(
            model_name='ad',
            name='link',
            field=models.URLField(blank=True, default='', verbose_name='Ad Link'),
        ),
        migrations.AlterField(
            model_name='ad',
            name='picture',
            field=models.FileField(blank=True, null=True, upload_to='b/%Y/%m/%d', verbose_name='Picture'),
        ),
        migrations.AlterField(
            model_name='ad',
            name='title',
            field=models.TextField(blank=True, default='', verbose_name='Ad Text'),
        ),
    ]



from dartcms.apps.ads.models import AdSection
from dartcms.utils.config import DartCMSConfig

app_name = 'adsection'

config = DartCMSConfig({
    'model': AdSection,
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '80%'},
            {'field': 'is_enabled', 'width': '20%'},
        ]
    }
})

urlpatterns = config.get_urls()



from dartcms.utils.config import DartCMSConfig
from dartcms.utils.loading import get_model

from .forms import FeedItemForm

app_name = 'feeditems'

FeedItem = get_model('feeds', 'FeedItem')

config = DartCMSConfig({
    'model': FeedItem,
    'parent_kwarg_name': 'feed',
    'parent_model_fk': 'feed_id',
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '60%'},
            {'field': 'is_visible', 'width': '20%'},
            {'field': 'date_published', 'width': '20%'},
        ],
        'search': [
            'name', 'date_published', 'is_visible'
        ]
    },
    'form': {
        'form_class': FeedItemForm,
    }
})

urlpatterns = config.get_urls()



from dartcms import get_model
from django.contrib import admin

OrderShippingType = get_model('shop', 'OrderShippingType')
OrderPaymentType = get_model('shop', 'OrderPaymentType')
OrderStatus = get_model('shop', 'OrderStatus')


class ModelAdmin(admin.ModelAdmin):
    pass

admin.site.register(OrderShippingType, ModelAdmin)
admin.site.register(OrderPaymentType, ModelAdmin)
admin.site.register(OrderStatus, ModelAdmin)



from __future__ import unicode_literals

from django.db import migrations
from django.utils import translation
from django.utils.translation import gettext_lazy as _

records = [
    dict(sort=1, slug='cash', name=_('Cash')),
    dict(sort=2, slug='cashless', name=_('Cashless')),
    dict(sort=3, slug='card', name=_('Credit card'))
]


def insert(apps, schema):
    from django.conf import settings
    translation.activate(settings.LANGUAGE_CODE)

    model = apps.get_model('shop', 'OrderPaymentType')
    for record in records:
        model.objects.create(**record)

    translation.deactivate()


def delete(apps, schema):
    model = apps.get_model('shop', 'OrderPaymentType')
    for record in records:
        model.objects.get(slug=record['slug']).delete()


class Migration(migrations.Migration):
    dependencies = [
        ('shop', '0003_auto_add_order_models'),
    ]

    operations = [
        migrations.RunPython(insert, delete)
    ]



import os
import sys

from setuptools import find_packages, setup

if sys.argv[-1] == 'publish':
    os.system('rm dist/*')
    os.system('python3 setup.py sdist')
    os.system('twine upload dist/*')
    sys.exit()

packages = find_packages()

setup(
    name='dartcms',
    version='0.2.0',
    description='DartCMS - open-source content management system for Django',
    long_description='DartCMS is an open-source content management system based on the popular '
                     'Django Framework. It is friendly for developers and end-users.',
    author='Dmitry Astrikov, Vyacheslav Martsinkevich',
    author_email='astrikov.d@gmail.com, master@neucom.ru',
    url='https://github.com/astrikov-d/dartcms',
    packages=packages,
    include_package_data=True,
    py_modules=['dartcms'],
    install_requires=[
        'Django>=3.0.0',
        'django-autoslug>=1.9.4',
        'django-extra-views>=0.7.1',
        'django-gravatar2>=1.4.0',
        'django-mptt>=0.8.4',
        'django-versatileimagefield>=1.9',
        'django-widget-tweaks>=1.4.1',
        'jsonfield>=1.0.3',
        'pytils>=0.3'
    ],
    license='MIT License',
    zip_safe=False,
    keywords='django cms dartcms',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
    ]
)



# Generated by Django 1.9.6 on 2016-07-06 06:54
from __future__ import unicode_literals

from django.db import migrations


def setup_relationships(apps, schema):
    PageModule = apps.get_model('pages', 'PageModule')

    feeds_module = PageModule.objects.get(slug='feeds')
    feeds_module.related_model = 'feeds.Feed'
    feeds_module.save(update_fields=['related_model'])

    shop_module = PageModule.objects.get(slug='shop')
    shop_module.related_model = 'shop.ProductCategory'
    shop_module.save(update_fields=['related_model'])


def drop_relationships(apps, schema):
    PageModule = apps.get_model('pages', 'PageModule')

    PageModule.objects.all().update(related_model=None)


class Migration(migrations.Migration):
    dependencies = [
        ('pages', '0004_insert_pagemodules'),
    ]

    operations = [
        migrations.RunPython(setup_relationships, drop_relationships)
    ]



from dartcms.apps.modules.models import ModulePermission
from django import template

try:
    import Image, ImageOps
except ImportError:
    from PIL import Image, ImageOps

register = template.Library()


#######################################################################################
# Module permissions.
# Usage:
# {% if module|has_permission:'CREATE %}
# ...
# {% endif %}
#######################################################################################
@register.simple_tag()
def check_module_permission(cms_module, user, permission_type):
    if user:
        perms = ModulePermission.objects.filter(user=user, module=cms_module).first()
        if perms:
            mapping = {
                'CREATE': 'can_insert',
                'UPDATE': 'can_update',
                'DELETE': 'can_delete',
            }
            return getattr(perms, mapping.get(permission_type))
    return False



# Generated by Django 1.9.7 on 2016-07-11 16:27
from __future__ import unicode_literals

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filemanager', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='file',
            name='folder',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='files', to='filemanager.Folder'),
        ),
    ]



# Generated by Django 1.9.6 on 2016-07-05 02:34
from __future__ import unicode_literals

import django.db.models.deletion
import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Ad',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_from', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Start Date')),
                ('date_to', models.DateTimeField(default=django.utils.timezone.now, verbose_name='End Date')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('title', models.TextField(blank=True, default=b'', verbose_name='Ad Text')),
                ('link', models.URLField(blank=True, default=b'', verbose_name='Ad Link')),
                ('code', models.TextField(blank=True, default=b'', verbose_name='Embed Code')),
                ('bg', models.CharField(blank=True, default=b'', max_length=255, verbose_name='Background Color')),
                ('views', models.IntegerField(default=0, verbose_name='Views')),
                ('picture', models.FileField(blank=True, null=True, upload_to=b'b/%Y/%m/%d', verbose_name='Picture')),
                ('is_enabled', models.BooleanField(default=True, verbose_name='Is Enabled')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_changed', models.DateTimeField(auto_now=True)),
            ],
            options={
                'ordering': ['name'],
                'abstract': False,
                'verbose_name': 'ad',
                'verbose_name_plural': 'ads',
            },
        ),
        migrations.CreateModel(
            name='AdPlace',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('slug', models.SlugField(unique=True)),
                ('is_enabled', models.BooleanField(default=True, verbose_name='Is Enabled')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'ad place',
                'verbose_name_plural': 'ad places',
            },
        ),
        migrations.CreateModel(
            name='AdSection',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('is_enabled', models.BooleanField(default=True, verbose_name='Is Enabled')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'ad section',
                'verbose_name_plural': 'ad sections',
            },
        ),
        migrations.AddField(
            model_name='ad',
            name='place',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='ads_ad_related', to='ads.AdPlace', verbose_name='Ad Place'),
        ),
        migrations.AddField(
            model_name='ad',
            name='section',
            field=models.ManyToManyField(related_name='ads_ad_related', to='ads.AdSection', verbose_name='Section'),
        ),
    ]



from dartcms import get_model
from dartcms.utils.config import DartCMSConfig

from .forms import ProductForm

app_name = 'products'

Product = get_model('shop', 'Product')

config = DartCMSConfig({
    'model': Product,
    'parent_kwarg_name': 'section',
    'parent_model_fk': 'section_id',
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '40%'},
            {'field': 'code', 'width': '20%'},
            {'field': 'manufacturer', 'width': '20%'},
            {'field': 'residue', 'width': '10%'},
            {'field': 'price', 'width': '10%'},
        ]
    },
    'form': {
        'form_class': ProductForm,
    }
})

urlpatterns = config.get_urls()



from dartcms.utils.loading import is_model_registered
from django.db.models.signals import post_save, pre_delete, pre_save

from .abstract_models import *
from .signals import *

__all__ = []

if not is_model_registered('shop', 'ProductCatalog'):
    class ProductCatalog(AbstractProductCatalog):
        pass

    __all__.append('ProductCatalog')

if is_model_registered('shop', 'ProductSection'):
    section_model = get_model('shop', 'ProductSection')
else:
    class ProductSection(AbstractProductSection):
        pass

    __all__.append('ProductSection')

    section_model = ProductSection

if not is_model_registered('shop', 'ProductLabel'):
    class ProductLabel(AbstractProductLabel):
        pass

    __all__.append('ProductLabel')

if not is_model_registered('shop', 'ProductManufacturer'):
    class ProductManufacturer(AbstractProductManufacturer):
        pass

    __all__.append('ProductManufacturer')

if not is_model_registered('shop', 'Product'):
    class Product(AbstractProduct):
        pass

    __all__.append('Product')

if not is_model_registered('shop', 'ProductImage'):
    class ProductImage(AbstractProductImage):
        pass

    __all__.append('ProductImage')

if not is_model_registered('shop', 'OrderStatus'):
    class OrderStatus(AbstractOrderStatus):
        pass

    __all__.append('OrderStatus')

if not is_model_registered('shop', 'OrderPaymentType'):
    class OrderPaymentType(AbstractOrderPaymentType):
        pass

    __all__.append('OrderPaymentType')

if not is_model_registered('shop', 'OrderShippingType'):
    class OrderShippingType(AbstractOrderShippingType):
        pass

    __all__.append('OrderShippingType')

if not is_model_registered('shop', 'Order'):
    class Order(AbstractOrder):
        pass

    __all__.append('Order')

if not is_model_registered('shop', 'OrderDetail'):
    class OrderDetail(AbstractOrderDetail):
        pass

    __all__.append('OrderDetail')

pre_save.connect(pre_save_handler_section, sender=section_model)
post_save.connect(post_save_handler_section, sender=section_model)
pre_delete.connect(pre_delete_handler_section, sender=section_model)



# Generated by Django 1.9.6 on 2016-07-05 05:15
from __future__ import unicode_literals

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Module',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64, verbose_name='Name')),
                ('sort', models.IntegerField(default=1, verbose_name='Sort')),
                ('description', models.TextField(blank=True, default=b'', verbose_name='Description')),
                ('slug', models.SlugField(unique=True, verbose_name='Slug')),
                ('is_enabled', models.BooleanField(default=True, verbose_name='Is Enabled')),
            ],
            options={
                'ordering': ['group', 'sort'],
                'verbose_name': 'Module',
                'verbose_name_plural': 'Modules',
            },
        ),
        migrations.CreateModel(
            name='ModuleGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=64, verbose_name='Name')),
                ('fa', models.SlugField(verbose_name='FontAwesome class')),
                ('sort', models.IntegerField(default=1, verbose_name='Sort')),
                ('description', models.TextField(blank=True, default=b'', verbose_name='Description')),
            ],
            options={
                'ordering': ['sort'],
                'verbose_name': 'Module Group',
                'verbose_name_plural': 'Module Groups',
            },
        ),
        migrations.AddField(
            model_name='module',
            name='group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='modules', to='modules.ModuleGroup', to_field='slug', verbose_name='Group'),
        ),
        migrations.AddField(
            model_name='module',
            name='user',
            field=models.ManyToManyField(to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
    ]



# Generated by Django 1.9.6 on 2016-07-06 08:27
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('feeds', '0001_initial'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='feed',
            unique_together=set([]),
        ),
        migrations.RemoveField(
            model_name='feed',
            name='slug',
        ),
    ]



# Generated by Django 1.10.4 on 2016-12-14 02:39
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='UserGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64, verbose_name='Group name')),
                ('users', models.ManyToManyField(related_name='group_users', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'User group',
                'verbose_name_plural': 'User groups',
            },
        ),
    ]



from dartcms import get_model
from dartcms.utils.config import DartCMSConfig

app_name = 'ad'

Ad = get_model('ads', 'Ad')

config = DartCMSConfig({
    'model': Ad,
    'grid': {
        'grid_columns': [
            {'field': 'name', 'width': '30%'},
            {'field': 'place', 'width': '20%'},
            {'field': 'date_from', 'width': '20%'},
            {'field': 'date_to', 'width': '20%'},
            {'field': 'is_enabled', 'width': '10%'},
        ]
    }
})

urlpatterns = config.get_urls()



from dartcms.utils.loading import get_model
from django.conf import settings


def get_user_model():
    app_label, model_name = getattr(settings, 'AUTH_USER_MODEL', 'auth.User').split('.')
    return get_model(app_label, model_name)



from django.contrib.auth.base_user import BaseUserManager


class SiteUserManager(BaseUserManager):
    def get_queryset(self):
        return super(SiteUserManager, self).get_queryset().filter(is_staff=False)

    def create(self, **kwargs):
        kwargs.update({'is_staff': False})
        return super(SiteUserManager, self).create(**kwargs)



# Generated by Django 1.9.7 on 2016-07-13 03:18
from __future__ import unicode_literals

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ContactMessage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('author', models.CharField(max_length=255, verbose_name='Author')),
                ('message', models.TextField(verbose_name='Message')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('email', models.EmailField(blank=True, max_length=254, null=True, verbose_name='Email')),
                ('phone', models.CharField(blank=True, max_length=64, null=True, verbose_name='Phone')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FormType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(choices=[(b'contact', 'Contact form'), (b'question', 'Questions form')], verbose_name='Type ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
            ],
        ),
        migrations.CreateModel(
            name='QuestionMessage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('author', models.CharField(max_length=255, verbose_name='Author')),
                ('message', models.TextField(verbose_name='Message')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='feedback.FormType', verbose_name='Type')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='contactmessage',
            name='type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='feedback.FormType', verbose_name='Type'),
        ),
    ]



# Generated by Django 1.9.8 on 2016-08-01 16:07
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('feedback', '0002_auto_20160713_0349'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='formtype',
            options={'verbose_name': 'Form type', 'verbose_name_plural': 'Form types'},
        ),
    ]



# Generated by Django 1.10.4 on 2017-08-29 05:15
from __future__ import unicode_literals

import dartcms.utils.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0012_homepage_security'),
    ]

    operations = [
        migrations.AlterField(
            model_name='page',
            name='after_content',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='After Content'),
        ),
        migrations.AlterField(
            model_name='page',
            name='before_content',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Before Content'),
        ),
        migrations.AlterField(
            model_name='page',
            name='menu_name',
            field=models.CharField(default='', max_length=255, verbose_name='Menu name'),
        ),
        migrations.AlterField(
            model_name='page',
            name='redirect_url',
            field=models.CharField(blank=True, default='', max_length=255, verbose_name='URL for Redirect'),
        ),
        migrations.AlterField(
            model_name='page',
            name='security_type',
            field=models.CharField(choices=[('DEFAULT', 'Editable for all users'), ('BY_PARENT', 'Based on the parent page'), ('GROUPS_ONLY', 'Editable for specific groups')], default='BY_PARENT', max_length=16, verbose_name='Security type'),
        ),
        migrations.AlterField(
            model_name='page',
            name='seo_description',
            field=models.TextField(blank=True, default='', verbose_name='Description (meta description)'),
        ),
        migrations.AlterField(
            model_name='page',
            name='seo_keywords',
            field=models.TextField(blank=True, default='', verbose_name='Keywords (meta keywords)'),
        ),
        migrations.AlterField(
            model_name='page',
            name='slug',
            field=models.SlugField(blank=True, default='', verbose_name='URL'),
        ),
    ]



from django.contrib import admin

from .models import Module, ModuleGroup, ModulePermission


class ModuleGroupAdmin(admin.ModelAdmin):
    pass


admin.site.register(ModuleGroup, ModuleGroupAdmin)


class ModuleAdmin(admin.ModelAdmin):
    pass


admin.site.register(Module, ModuleAdmin)


class ModulePermissionAdmin(admin.ModelAdmin):
    pass


admin.site.register(ModulePermission, ModulePermissionAdmin)



from django.contrib.auth import login, logout
from django.shortcuts import redirect
from django.urls import reverse_lazy
from django.views.generic import FormView, RedirectView

from .forms import LoginForm


class LoginView(FormView):
    template_name = "dartcms/apps/auth/login.html"
    form_class = LoginForm

    def get_initial(self):
        if 'next' in self.request.GET:
            return {'next': self.request.GET['next']}
        return {}

    def form_valid(self, form):
        data = form.cleaned_data
        user = form.get_user()
        login(self.request, user)

        redirect_url = data.get('next', reverse_lazy('dartcms:dashboard:index'))
        return redirect(redirect_url)


class LogoutView(RedirectView):
    url = 'dartcms:dashboard:index'

    def get(self, request, *args, **kwargs):
        logout(request)
        return redirect(self.url)



from datetime import datetime

from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models
from django.template.defaultfilters import striptags, truncatewords
from django.utils.translation import ugettext_lazy as _


class SiteSettings(models.Model):
    TEXT = 'text'
    TEXTAREA = 'textarea'
    RICH = 'rich'
    DATE = 'date'
    FILE = 'file'
    SELECT = 'select'
    OBJECT = 'object'
    BOOLEAN = 'boolean'

    TYPE_CHOICES = (
        (TEXT, _('String')),
        (TEXTAREA, _('Text')),
        (RICH, _('Rich Editor')),
        (SELECT, _('Select')),
        (DATE, _('Date')),
        (FILE, _('File')),
        (OBJECT, _('Object')),
        (BOOLEAN, _('Checkbox')),
    )

    class Meta:
        ordering = ['slug']
        verbose_name = _('Site setting')
        verbose_name_plural = _('Site settings')

    def __str__(self):
        return '%s - %s' % (self.slug, self.description)

    @property
    def value(self):
        value = ''
        if self.type == self.OBJECT and self.content_type and self.object_id:
            value = self.content_type.model_class().objects.get(pk=self.object_id)

        return {
            self.DATE: self.date_value,
            self.FILE: self.file_value,
            self.BOOLEAN: 'Да' if self.boolean_value else 'Нет',
            self.OBJECT: value,
        }.get(self.type, self.text_value)

    @property
    def type_display(self):
        return self.get_type_display()

    @property
    def value_for_grid(self):
        return truncatewords(striptags(self.value), 10)

    slug = models.SlugField(_('Identifier'), max_length=30, unique=True)
    description = models.TextField(_('Description'), default='')
    type = models.CharField(_('Type'), max_length=10, choices=TYPE_CHOICES, default=TEXT, blank=True)
    text_value = models.TextField(_('Value for text type'), default='', blank=True)
    date_value = models.DateTimeField(_('Value for date type'), blank=True, null=True, default=datetime.now)
    file_value = models.FileField(_('Value for file'), upload_to='vars', blank=True, null=True)
    boolean_value = models.BooleanField(_('Value for boolean'), default=False)
    options = models.TextField(_('Options for select type (use ";" as separator)'), default='', blank=True)
    object_id = models.PositiveIntegerField(null=True, blank=True)
    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE, null=True, blank=True)
    content_object = GenericForeignKey('content_type', 'object_id')



# Generated by Django 1.10.4 on 2016-12-14 02:58
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usergroup',
            name='users',
            field=models.ManyToManyField(related_name='user_groups', to=settings.AUTH_USER_MODEL),
        ),
    ]



from django.db import models
from django.utils.translation import ugettext_lazy as _

FORM_TYPES = (
    ('contact', _('Contact form')),
    ('question', _('Questions form'))
)


class FormType(models.Model):
    class Meta:
        app_label = 'feedback'
        verbose_name = _('Form type')
        verbose_name_plural = _('Form types')

    slug = models.SlugField(verbose_name=_('Type ID'), choices=FORM_TYPES)
    name = models.CharField(max_length=255, verbose_name=_('Name'))

    def __str__(self):
        return self.name


class AbstractBaseMessage(models.Model):
    class Meta:
        app_label = 'feedback'
        abstract = True

    def __str__(self):
        return self.author

    type = models.ForeignKey(FormType, verbose_name=_('Type'), on_delete=models.CASCADE)
    author = models.CharField(max_length=255, verbose_name=_('Author'))
    message = models.TextField(verbose_name=_('Message'))
    date_created = models.DateTimeField(auto_now_add=True)


class AbstractQuestionMessage(AbstractBaseMessage):
    class Meta:
        verbose_name = _('Question message')
        verbose_name_plural = _('Question messages')
        app_label = 'feedback'
        abstract = True

    answer = models.TextField(verbose_name=_('Answer'), blank=True, null=True)
    is_visible = models.BooleanField(verbose_name=_('Is Visible'), default=False)


class AbstractContactMessage(AbstractBaseMessage):
    class Meta:
        verbose_name = _('Contact message')
        verbose_name_plural = _('Contact messages')
        app_label = 'feedback'
        abstract = True

    email = models.EmailField(verbose_name=_('Email'), blank=True, null=True)
    phone = models.CharField(max_length=64, verbose_name=_('Phone'), blank=True, null=True)
